@@ -5,7 +5,7 @@ package SHARYANTO::Role::BorderStyle;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.65'; # VERSION
+our $VERSION = '0.66'; # VERSION
 
 with 'SHARYANTO::Role::TermAttrs';
 
@@ -114,7 +114,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -122,7 +122,7 @@ SHARYANTO::Role::BorderStyle - Role for class wanting to support border styles
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 DESCRIPTION
 
@@ -159,6 +159,11 @@ A character can also be a coderef that will be called with C<< ($self, %args)
 >>. Arguments in C<%args> contains information such as C<name>, C<y>, C<x>, C<n>
 (how many times should character be repeated), etc.
 
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
 =head1 ATTRIBUTES
 
 =head2 border_style => HASH
@@ -177,6 +182,23 @@ Pick border character from border style (and optionally repeat it C<$repeat>
 times). C<\%args> is a hashref to be supplied to the coderef if the 'chars'
 value from the style is a coderef.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/SHARYANTO-Roles>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Roles>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Roles>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
@@ -188,9 +210,4 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =cut
