@@ -4,7 +4,7 @@ use 5.010;
 use Log::Any '$log';
 use Moo::Role;
 
-our $VERSION = '0.65'; # VERSION
+our $VERSION = '0.66'; # VERSION
 
 has langs => (
     is => 'rw',
@@ -60,7 +60,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -68,7 +68,7 @@ SHARYANTO::Role::I18NMany - Role for internationalized class
 
 =head1 VERSION
 
-version 0.65
+version 0.66
 
 =head1 DESCRIPTION
 
@@ -76,6 +76,11 @@ This role is like L<SHARYANTO::Role::I18N> but for class that wants to localize
 text for more than one languages. Its locl() accepts desired language as its
 first argument.
 
+=head1 FUNCTIONS
+
+
+None are exported by default, but they are exportable.
+
 =head1 ATTRIBUTES
 
 =head2 langs => ARRAY
@@ -97,6 +102,23 @@ Get language handle for a certain language. $lang is required.
 
 Shortcut for C<$doc->lh($lang)->maketext(@args)>.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/SHARYANTO-Roles>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Roles>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Roles>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
@@ -108,9 +130,4 @@ This software is copyright (c) 2013 by Steven Haryanto.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =cut
